/*!
 * @file main.c
 * @brief LDC Click example
 *
 * # Description
 * This example showcases abillity of the device to detect 
 * metal objects. It configures device for reading data from 
 * channel 0, checks if ID's are OK and reads data when interrupt 
 * is asserted and logs result.
 *
 * The demo application is composed of two sections :
 *
 * ## Application Init
 * Initialization of communication modules (I2C, UART) and 
 * additional pins. Then configures device for reading data from 
 * channel 0, and checks if device ID's are correctly read.
 *
 * ## Application Task
 * Chekcs if interrupt pin is asserted, if so reads data from channel 0.
 * If no error is detected logs ADC data read from device. It will log 
 * error data if some are detected.
 *
 * @author Luka Filipovic
 *
 */

#include "board.h"
#include "log.h"
#include "ldc.h"

static ldc_t ldc;
static log_t logger;

void application_init ( void ) 
{
    log_cfg_t log_cfg;  /**< Logger config object. */
    ldc_cfg_t ldc_cfg;  /**< Click config object. */

    // Logger initialization.
    LOG_MAP_USB_UART( log_cfg );
    log_cfg.level = LOG_LEVEL_DEBUG;
    log_cfg.baud = 115200;
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    ldc_cfg_setup( &ldc_cfg );
    LDC_MAP_MIKROBUS( ldc_cfg, MIKROBUS_1 );
    err_t init_flag = ldc_init( &ldc, &ldc_cfg );
    if ( I2C_MASTER_ERROR == init_flag ) 
    {
        log_error( &logger, " Application Init Error. " );
        log_info( &logger, " Please, run program again... " );
        for ( ; ; );
    }

    if ( ldc_default_cfg ( &ldc ) < 0 )
    {
        log_error( &logger, " Default configuration. " );
        for ( ; ; );
    }
    
    uint16_t temp_data = 0;
    ldc_generic_read( &ldc, LDC_REG_MANUFACTURER_ID, &temp_data );
    log_printf( &logger, "> Manufacturer ID: 0x%.4X\r\n", temp_data );
    if ( temp_data != LDC_MANUFACTURER_ID )
    {
        log_error( &logger, " Manufacturer ID. " );
        for ( ; ; );
    }
    
    ldc_generic_read( &ldc, LDC_REG_DEVICE_ID, &temp_data );
    log_printf( &logger, "> Device ID 0x%.4X\r\n", temp_data );
    if ( temp_data != LDC_DEVICE_ID )
    {
        log_error( &logger, " Device ID. " );
        for ( ; ; );
    }
    
    Delay_ms( 1000 );
    log_info( &logger, " Application Task " );
}

void application_task ( void ) 
{
    if ( ldc_get_interrupt( &ldc ) )
    {
        uint16_t temp_data = 0;
        ldc_generic_read( &ldc, LDC_REG_DATA_CH0, &temp_data );
        
        if ( !( temp_data >> 12 ) )
        {
            log_printf( &logger, "> Data: %u\r\n", temp_data & 0xFFF );
            Delay_ms( 500 );
        }
        else
        {
            temp_data >>= 12;
            
            if ( temp_data & 0x8 )
            {
                log_error( &logger, " Under-range" );
            }
            if ( temp_data & 0x4 )
            {
                log_error( &logger, " Over-range" );
            }
            if ( temp_data & 0x3 )
            {
                log_error( &logger, " Watchdog" );
            }
        }
    }
}

void main ( void ) 
{
    application_init( );

    for ( ; ; ) 
    {
        application_task( );
    }
}

// ------------------------------------------------------------------------ END
